@@ -368,7 +368,7 @@ on_get_gps_nmea_ready (GObject      *source_object,
         }
 
         if (is_location_gga_same (manager, gga)) {
-                g_debug ("New GGA trace is same as last one");
+                g_debug ("New GGA trace is same as last one: %s", gga);
                 return;
         }
         g_clear_object (&priv->location_nmea);
@@ -544,6 +544,23 @@ on_mm_modem_state_notify (GObject    *gobject,
         g_object_unref (mm_modem);
 }
 
+static void
+on_gps_refresh_rate_set (GObject      *source_object,
+                         GAsyncResult *res,
+                         gpointer      user_data)
+{
+        gboolean ret;
+        GError *error = NULL;
+
+        ret = mm_modem_location_set_gps_refresh_rate_finish
+                (MM_MODEM_LOCATION (source_object), res, &error);
+        if (!ret) {
+                g_warning ("Failed to set GPS refresh rate: %s",
+                           error->message);
+                g_error_free (error);
+        }
+}
+
 static void
 on_mm_object_added (GDBusObjectManager *object_manager,
                     GDBusObject        *object,
@@ -583,6 +600,12 @@ on_mm_object_added (GDBusObjectManager *object_manager,
         manager->priv->modem = mm_modem;
         manager->priv->modem_location = mm_object_get_modem_location (mm_object);
 
+        mm_modem_location_set_gps_refresh_rate (manager->priv->modem_location,
+                                                0,
+                                                manager->priv->cancellable,
+                                                on_gps_refresh_rate_set,
+                                                user_data);
+
         g_signal_connect (G_OBJECT (manager->priv->modem_location),
                           "notify::location",
                           G_CALLBACK (on_location_changed),
